@@ -64,6 +64,10 @@ class Refund(Base):
     def created_at(self):
         return self._get_property('createdAt')
 
+    @property
+    def metadata(self):
+        return self._get_property('metadata')
+
     # documented _links
 
     @property
